ObjectiveBuilder

Struct ObjectiveBuilder 

pub struct ObjectiveBuilder { /* private fields */ }
Builder for ergonomic creation of objectives.

Returned by Objective::minimize or Objective::maximize, allows setting optional fields like name or priority.

Implementations

Source

impl ObjectiveBuilder

pub fn priority(self, p: u32) -> Self

Sets a priority for multi-objective optimization.

Higher priority objectives are optimized first.

Example
let x = model.add_var().finish(); // VarId
let obj = Objective::maximize(2.0 * x).priority(1);
pub fn name<S: Into<String>>(self, name: S) -> Objective

Sets a human-readable name for the objective and returns the final Objective.

Example
let x = model.add_var().finish(); // VarId
let obj = Objective::maximize(2.0 * x).name("Profit");