VarId

Struct VarId 

pub struct VarId(pub usize);
A unique identifier for a variable in a model.

This is used internally by the solver and the model to index variable values.

Tuple Fields

0: usize

Implementations

Source

impl VarId

pub fn leq(self, rhs: f64) -> Constraint

Creates a <= constraint: self <= rhs.

pub fn geq(self, rhs: f64) -> Constraint

Creates a >= constraint: self >= rhs.

pub fn eq(self, rhs: f64) -> Constraint

Creates a == constraint: self == rhs.