pub struct VarId(pub usize);Expand description
A unique identifier for a variable in a model.
This is used internally by the solver and the model to index variable values.
Tuple Fields
0: usizeImplementations
Sourceimpl VarId
impl VarId
Sourcepub fn leq(self, rhs: f64) -> Constraint
pub fn leq(self, rhs: f64) -> Constraint
Creates a <= constraint: self <= rhs.
Sourcepub fn geq(self, rhs: f64) -> Constraint
pub fn geq(self, rhs: f64) -> Constraint
Creates a >= constraint: self >= rhs.
Sourcepub fn eq(self, rhs: f64) -> Constraint
pub fn eq(self, rhs: f64) -> Constraint
Creates a == constraint: self == rhs.